@@ -1,8 +1,24 @@
 
 """
-  Copyright (c) 2014, SunSpec Alliance
-  All Rights Reserved
+    Copyright (C) 2017 SunSpec Alliance
 
+    Permission is hereby granted, free of charge, to any person obtaining a
+    copy of this software and associated documentation files (the "Software"),
+    to deal in the Software without restriction, including without limitation
+    the rights to use, copy, modify, merge, publish, distribute, sublicense,
+    and/or sell copies of the Software, and to permit persons to whom the
+    Software is furnished to do so, subject to the following conditions:
+
+    The above copyright notice and this permission notice shall be included
+    in all copies or substantial portions of the Software.
+
+    THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
+    IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
+    FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL
+    THE AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
+    LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING
+    FROM, OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS
+    IN THE SOFTWARE.
 """
 
 import os
@@ -138,7 +154,7 @@ class ModbusClientRTU(object):
         req += struct.pack('>H', computeCRC(req))
         
         if trace_func:
-            s = '%s:%s ->' % (self.name, str(slave_id))
+            s = '%s:%s[addr=%s] ->' % (self.name, str(slave_id), addr)
             for c in req:
                 s += '%02X' % (ord(c))
             trace_func(s)
@@ -165,7 +181,7 @@ class ModbusClientRTU(object):
                 raise ModbusClientTimeout('Response timeout')
 
         if trace_func:
-            s = '%s:%s <--' % (self.name, str(slave_id))
+            s = '%s:%s[addr=%s] <--' % (self.name, str(slave_id), addr)
             for c in resp:
                 s += '%02X' % (ord(c))
             trace_func(s)
@@ -216,7 +232,7 @@ class ModbusClientRTU(object):
         req += struct.pack('>H', computeCRC(req))
 
         if trace_func:
-            s = '%s:%s ->' % (self.name, str(slave_id))
+            s = '%s:%s[addr=%s] ->' % (self.name, str(slave_id), addr)
             for c in req:
                 s += '%02X' % (ord(c))
             trace_func(s)
@@ -243,7 +259,7 @@ class ModbusClientRTU(object):
                 raise ModbusClientTimeout('Response timeout')
 
         if trace_func:
-            s = '%s:%s <--' % (self.name, str(slave_id))
+            s = '%s:%s[addr=%s] <--' % (self.name, str(slave_id), addr)
             for c in resp:
                 s += '%02X' % (ord(c))
             trace_func(s)
@@ -377,7 +393,7 @@ class ModbusClientDeviceTCP(object):
         req = struct.pack('>HHHBBHH', 0, 0, TCP_READ_REQ_LEN, int(self.slave_id), op, int(addr), int(count))
 
         if self.trace_func:
-            s = '%s:%s:%s ->' % (self.ipaddr, str(self.ipport), str(self.slave_id))
+            s = '%s:%s:%s[addr=%s] ->' % (self.ipaddr, str(self.ipport), str(self.slave_id), addr)
             for c in req:
                 s += '%02X' % (ord(c))
             self.trace_func(s)
@@ -407,7 +423,7 @@ class ModbusClientDeviceTCP(object):
             except_code = ord(resp[TCP_HDR_LEN + 2])
 
         if self.trace_func:
-            s = '%s:%s:%s <--' % (self.ipaddr, str(self.ipport), str(self.slave_id))
+            s = '%s:%s:%s[addr=%s] <--' % (self.ipaddr, str(self.ipport), str(self.slave_id), addr)
             for c in resp:
                 s += '%02X' % (ord(c))
             self.trace_func(s)
@@ -461,7 +477,7 @@ class ModbusClientDeviceTCP(object):
         req += data
 
         if self.trace_func:
-            s = '%s:%s:%s ->' % (self.ipaddr, str(self.ipport), str(self.slave_id))
+            s = '%s:%s:%s[addr=%s] ->' % (self.ipaddr, str(self.ipport), str(self.slave_id), addr)
             for c in req:
                 s += '%02X' % (ord(c))
             self.trace_func(s)
@@ -491,7 +507,7 @@ class ModbusClientDeviceTCP(object):
             except_code = ord(resp[TCP_HDR_LEN + 2])
 
         if self.trace_func:
-            s = '%s:%s:%s <--' % (self.ipaddr, str(self.ipport), str(self.slave_id))
+            s = '%s:%s:%s[addr=%s] <--' % (self.ipaddr, str(self.ipport), str(self.slave_id), addr)
             for c in resp:
                 s += '%02X' % (ord(c))
             self.trace_func(s)
